@@ -20,6 +20,8 @@
 
 
 from ConfigParser import SafeConfigParser
+import os
+import stat
 # Work around relative import behavior.  The below is equivalent to
 # from oauth import oauth
 oauth = __import__('oauth.oauth', {}).oauth
@@ -157,13 +159,16 @@ class OAuthAuthorizer(HttpAuthorizer):
     def save_to_path(self, path):
         """Convenience method for saving credentials to a file.
 
-        Create the file, call self.save(), and close the file. Existing
-        files are overwritten.
+        Create the file, call self.save(), and close the
+        file. Existing files are overwritten. The resulting file will
+        be readable and writable only by the user.
 
         :param path: In which file the credential file should be saved.
         :type path: string
         """
-        credentials_file = open(path, 'w')
+        credentials_file = os.fdopen(
+            os.open(path, (os.O_CREAT | os.O_TRUNC | os.O_WRONLY),
+                    (stat.S_IREAD | stat.S_IWRITE)), 'w')
         self.save(credentials_file)
         credentials_file.close()
 
