@@ -329,7 +329,7 @@ class Resource(RestfulBase):
         if self._wadl_resource.representation is None:
             # Get a representation of the linked resource.
             representation = self._root._browser.get(self._wadl_resource)
-            representation = simplejson.loads(representation)
+            representation = simplejson.loads(unicode(representation))
             type_link = representation['resource_type_link']
             if (type_link is not None
                 and type_link != self._wadl_resource.type_url):
@@ -683,15 +683,10 @@ class Entry(Resource):
         # PATCH the new representation to the 'self' link.  It's possible that
         # this will cause the object to be permanently moved.  Catch that
         # exception and refresh our representation.
-        try:
-            response, content = self._root._browser.patch(
-                URI(self.self_link), representation, headers)
-        except HTTPError, error:
-            if error.response.status == 301:
-                response = error.response
-                self.lp_refresh(error.response['location'])
-            else:
-                raise
+        response, content = self._root._browser.patch(
+            URI(self.self_link), representation, headers)
+        if response.status == 301:
+            self.lp_refresh(response['location'])
         self._dirty_attributes.clear()
 
         content_type = response['content-type']
@@ -888,6 +883,7 @@ class CollectionWithKeyBasedLookup(Collection):
         """Look up a slice, or a subordinate resource by unique ID."""
         if isinstance(key, slice):
             return super(CollectionWithKeyBasedLookup, self).__getitem__(key)
+
         try:
             url = self._get_url_from_id(key)
         except NotImplementedError:
@@ -895,6 +891,23 @@ class CollectionWithKeyBasedLookup(Collection):
         if url is None:
             raise KeyError(key)
 
+        shim_resource = self(key)
+        try:
+            shim_resource._ensure_representation()
+        except HTTPError, e:
+            raise KeyError(key)
+        return shim_resource
+
+    def __call__(self, key):
+        """Retrieve a member from this collection without looking it up."""
+
+        try:
+            url = self._get_url_from_id(key)
+        except NotImplementedError:
+            raise TypeError("unsubscriptable object")
+        if url is None:
+            raise ValueError(key)
+
         if self.collection_of is not None:
             # We know what kind of resource is at the other end of the
             # URL. There's no need to actually fetch that URL until
